Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(387)

Unified Diff: content/browser/wake_lock/wake_lock_browsertest.cc

Issue 2921823002: Rationalize WakeLock naming conventions (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/wake_lock/wake_lock_browsertest.cc
diff --git a/content/browser/wake_lock/wake_lock_browsertest.cc b/content/browser/wake_lock/wake_lock_browsertest.cc
index 57f38146dc2c65947b5731e0e788f62946515e4a..663fe3479c154645e377f7ce84da49c87d8e025f 100644
--- a/content/browser/wake_lock/wake_lock_browsertest.cc
+++ b/content/browser/wake_lock/wake_lock_browsertest.cc
@@ -67,7 +67,7 @@ class WakeLockTest : public ContentBrowserTest {
return GetNestedFrameNode()->current_frame_host();
}
- device::mojom::WakeLockService* GetRendererWakeLock() {
+ device::mojom::WakeLock* GetRendererWakeLock() {
return GetWebContentsImpl()->GetRendererWakeLock();
}
@@ -84,9 +84,9 @@ class WakeLockTest : public ContentBrowserTest {
void WaitForPossibleUpdate() {
// As Mojo channels have no common FIFO order in respect to each other and
// to the Chromium IPC, we cannot assume that when screen.keepAwake state
// is changed from within a script, mojom::WakeLockService will receive an
// update request before ExecuteScript() returns. Therefore, some time slack
// is needed to make sure that mojom::WakeLockService has received any
// possible update requests before checking the resulting wake lock state.
base::PlatformThread::Sleep(TestTimeouts::tiny_timeout());
RunAllPendingInMessageLoop();
@@ -84,9 +84,9 @@ class WakeLockTest : public ContentBrowserTest {
// As Mojo channels have no common FIFO order in respect to each other and
// to the Chromium IPC, we cannot assume that when screen.keepAwake state
- // is changed from within a script, mojom::WakeLockService will receive an
+ // is changed from within a script, mojom::WakeLock will receive an
// update request before ExecuteScript() returns. Therefore, some time slack
@@ -84,9 +84,9 @@ class WakeLockTest : public ContentBrowserTest {
// update request before ExecuteScript() returns. Therefore, some time slack
- // is needed to make sure that mojom::WakeLockService has received any
+ // is needed to make sure that mojom::WakeLock has received any
// possible update requests before checking the resulting wake lock state.
base::PlatformThread::Sleep(TestTimeouts::tiny_timeout());
« no previous file with comments | « content/browser/renderer_host/render_widget_host_impl.cc ('k') | content/browser/web_contents/web_contents_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698